@@ -293,12 +293,21 @@ class Provider(BaseProvider):
         # In this case, call to API will return 409 HTTP error.
         # We use the Retry extension to retry the requests until
         # we get a processable response (402 HTTP status, or an HTTP error != 409)
-        retries = Retry(
-            total=10,
-            backoff_factor=0.5,
-            status_forcelist=[409],
-            allowed_methods=frozenset(["GET", "PUT", "POST", "DELETE", "PATCH"]),
-        )
+        try:
+            retries = Retry(
+                total=10,
+                backoff_factor=0.5,
+                status_forcelist=[409],
+                allowed_methods=frozenset(["GET", "PUT", "POST", "DELETE", "PATCH"]),
+            )
+        except TypeError:
+            # Support for urllib3<1.26
+            retries = Retry(
+                total=10,
+                backoff_factor=0.5,
+                status_forcelist=[409],
+                method_whitelist=frozenset(["GET", "PUT", "POST", "DELETE", "PATCH"]),
+            )
 
         session = requests.Session()
         session.mount("https://", HTTPAdapter(max_retries=retries))
